@@ -1,3 +1,5 @@
+from http import HTTPStatus
+
 from django.test import TestCase
 
 from allauth.socialaccount.providers.edmodo.provider import EdmodoProvider
@@ -10,7 +12,7 @@ class EdmodoTests(OAuth2TestsMixin, TestCase):
 
     def get_mocked_response(self):
         return MockedResponse(
-            200,
+            HTTPStatus.OK,
             """
 {
   "url": "https://api.edmodo.com/users/74721257",
