@@ -1,3 +1,5 @@
+from http import HTTPStatus
+
 from django.test import TestCase
 
 from allauth.socialaccount.providers.wahoo.provider import WahooProvider
@@ -11,7 +13,7 @@ class WahooTests(OAuth2TestsMixin, TestCase):
     def get_mocked_response(self):
         # https://cloud-api.wahooligan.com/#users
         return MockedResponse(
-            200,
+            HTTPStatus.OK,
             """
             {
               "id": 60462,
